@@ -1,4 +1,3 @@
-
 # library(stringr)
 # library(plyr)
 # library(XML)
@@ -115,7 +114,7 @@ api.url.maker=function(endyear, span, key, variables, dataset, geo.call) {
   api.for=paste0("for=",paste(names(api.for(geo.call)), api.for(geo.call), sep=":"))
   api.in=paste0(paste(names(api.in(geo.call)), api.in(geo.call), sep=":"), collapse="+")
   if (!identical(api.in, "")) api.in=paste0("&in=",api.in)
-  api.url=paste0("http://api.census.gov/data/", endyear, "/" , dataset, span, "?key=", key, "&get=", variables, ",NAME&", api.for, api.in)
+  api.url=paste0("https://api.census.gov/data/", endyear, "/" , dataset, span, "?key=", key, "&get=", variables, ",NAME&", api.for, api.in)
   api.url
 }
 
@@ -774,7 +773,7 @@ globalVariables(c("fips.state","fips.school","fips.county.subdivision", "fips.am
     if (check==T){
       for (i in 1:length(geo.set.obj)){
         cat(paste("Testing geography item ", i,": ", name(geo.list(geo.set.obj[i])), " .... ", sep=""))
-        obj.test=acs.fetch(endyear=2010, geography=geo.set.obj[i], key=key, variable="B01001_001",  lookup=F)
+        obj.test=acs.fetch(endyear=2014, geography=geo.set.obj[i], key=key, variable="B01001_001",  lookup=F)
         cat("OK.\n")
       }
     }
@@ -844,11 +843,11 @@ setClass(Class="acs.lookup", representation =
   # doc.url is path to census file for XML variables
       if(dataset=="acs") {
         doc.string=paste(dataset,"_", span,"yr_", endyear,"_var.xml.gz", sep="")
-        doc.url=paste("http://api.census.gov/data/", endyear,"/acs",span,"/variables.xml", sep="")
+        doc.url=paste("https://api.census.gov/data/", endyear,"/acs",span,"/variables.xml", sep="")
       }
       if(dataset=="sf1" | dataset=="sf3"){
         doc.string=paste(dataset,"_", endyear,".xml.gz", sep="")
-        doc.url=paste("http://api.census.gov/data/", endyear, "/", dataset, "/variables.xml", sep="")
+        doc.url=paste("https://api.census.gov/data/", endyear, "/", dataset, "/variables.xml", sep="")
         span=0
       }
       # first look for XML table internally
@@ -859,7 +858,11 @@ setClass(Class="acs.lookup", representation =
       # next check online at census site
       else if(url.exists(doc.url))
       {
-          doc=xmlInternalTreeParse(doc.url)
+          temp <- getURL(doc.url, ssl.verifyPeer=FALSE)
+          doc=xmlInternalTreeParse(temp)
+          # changed in v 2.1 due to https issue;
+          # in v 2.0, previous two lines were just this:
+          #   doc=xmlInternalTreeParse(doc.url)
       }
       # finally, check personal eglenn archive
       else if(url.exists(paste("http://web.mit.edu/eglenn/www/acs/acs-variables/", doc.string, sep="")))
@@ -1050,6 +1053,7 @@ read.acs=function(filename, endyear="auto", span="auto",
       datacols=datacols[-geocols]
       in.data=in.data[,c(geocols,datacols)]
       in.data[in.data=="*****"]=0
+      in.data[in.data=="-555555555"]=0
       for (i in (length(geocols)+1):length(in.data)) {
         in.data[[i]]=gsub(",", "", in.data[[i]])
         in.data[[i]]=as.numeric(in.data[[i]])  
@@ -1227,6 +1231,7 @@ acs.fetch=function(endyear, span=5, geography, table.name,
         }
         datacols=1:(length(in.data)-geo.length)
         in.data[in.data=="*****"]=0
+        in.data[in.data=="-555555555"]=0
         in.data[[1]]=gsub("[","",in.data[[1]], fixed=T )
         in.data[[length(in.data)]]=gsub("]","",in.data[[length(in.data)]], fixed=T )
                                             # clean brackets
@@ -1387,7 +1392,7 @@ setReplaceMethod(f="[", signature="acs",
       return(x)
     })
 
-cbind.acs=function(e1, e2) {
+cbind.acs=function(e1, e2, ...) {
   if (e1@endyear != e2@endyear | e1@span != e2@span) {
     warning("** acs objects x and y must have same endyear and span;\nreturning NA **")
     return(NA)}
@@ -1401,7 +1406,7 @@ cbind.acs=function(e1, e2) {
   acs.obj
 }
 
-rbind.acs=function(e1, e2) {
+rbind.acs=function(e1, e2, ...) {
   if (e1@endyear != e2@endyear | e1@span != e2@span) {
     warning("** acs objects x and y must have same endyear and span;\nreturning NA **")
     return(NA)}
@@ -1749,6 +1754,85 @@ if (!isGeneric("apply")) {
   setGeneric("apply", def=function(X, MARGIN, FUN, ...){standardGeneric("apply")})}else{}
 setMethod("apply", signature="acs", def=function(X, MARGIN, FUN, ...){.apply.acs(X, MARGIN, FUN, ...)})
 
+setMethod("plot",
+    signature(x = "acs"),
+    function (x, conf.level=.95, err.col="red", err.lwd=1,
+    err.pch="-", err.cex=2, err.lty=2, x.res=300, labels="auto",
+    by="geography", true.min=T, ...) 
+    {
+      # internal plot function to plot individual x-y plots with conf
+      # intervals, assume that either i or j or length 1
+      plot.xy.acs=function(x, object, conf.int.upper, conf.int.lower, estimates, labels, xlab, ylab, ...){
+        if(missing(xlab)) xlab=""
+        if(missing(ylab)) ylab=""       
+        plot(rep(x,2), c(conf.int.upper, conf.int.lower), type="n", xaxt="n", xlab=xlab, ylab=ylab,...)
+        axis(side=1, labels=labels, at=x, ...)
+        lines(x=matrix(c(x,x,rep(NA, length(x))), ncol=length(x), byrow=T), matrix(c(conf.int.lower, conf.int.upper, rep(NA, length(x))), ncol=length(x), byrow=T), col=err.col, lwd=err.lwd, lty=err.lty)
+        points(x, conf.int.upper, pch=err.pch, cex=err.cex, col=err.col)
+        points(x, conf.int.lower, pch=err.pch, cex=err.cex, col=err.col)
+        points(x, estimates,...)
+      }
+      acs.density.plot=function(x, type="l", xlim,
+        xlab=acs.colnames(x), ylab="Density Distribution",
+        conf.level, col="black", err.col, err.lwd, err.lty,
+        x.res, ...){
+        est=estimate(x)
+        err=standard.error(x)
+        if (missing(xlim)) xlim=c(est-(4*err), est+(4*err))
+        x.vals=seq(from=xlim[1], to=xlim[2], by=(xlim[2]-xlim[1])/x.res)
+        plot(x.vals, dnorm(x.vals, mean=est, sd=err), type=type,
+        xlab=xlab, ylab=ylab, col=col,...)
+      if (conf.level) {abline(v=qnorm(mean=est, sd=err, p=c(((1-conf.level)/2), (1-((1-conf.level)/2)))), col=err.col, lwd=err.lwd, lty=err.lty)}
+        }
+      i=dim(x)[1]
+      j=dim(x)[2]
+      if (length(x)==1) {
+        acs.density.plot(x, conf.level=conf.level, err.col=err.col,
+        err.lwd=err.lwd, err.lty=err.lty, x.res=x.res, ...)
+      } else if (i == 1 | j == 1){
+        con=confint(x, level=conf.level)
+        conf.int.upper=NA
+        conf.int.lower=NA
+        estimates=NA
+        if (i == 1) {                               # one row
+          if (identical(labels, "auto")) labels=acs.colnames(x)
+          for (k in 1:j){
+            conf.int.upper[k]=as.numeric(con[[k]][2])
+            if (true.min==T) {
+              conf.int.lower[k]=as.numeric(con[[k]][1])
+            } else {if (true.min==F) {true.min=0}
+                    conf.int.lower[k]=max(true.min, as.numeric(con[[k]][1]))}
+            estimates[k]=estimate(x)[1,k]
+            }}
+          else        {
+            if (identical(labels, "auto")) labels=geography(x)[[1]]
+          for (k in 1:i){                       # one column
+            conf.int.upper[k]=as.numeric(con[[1]][k,2])
+            if (true.min==T) {
+              conf.int.lower[k]=con[[1]][k,1]
+            } else {if (true.min==F) {true.min=0}
+                    conf.int.lower[k]=max(true.min, con[[1]][k,1])}
+            estimates[k]=estimate(x)[k,1]
+          }}
+        plot.xy.acs(x=1:max(i,j), object=x, conf.int.upper=conf.int.upper, conf.int.lower=conf.int.lower, estimates=estimates, labels=labels,...)
+      } else {
+        if (by=="geography"){
+          par(mfrow=c(i, 1))
+        for (k in 1:i){
+          plot(x[k,], sub=geography(x)[k,1], conf.level=conf.level, err.col=err.col, err.lwd=err.lwd, err.pch=err.pch, err.cex=err.cex, err.lty=err.lty, labels=labels,...)
+        }        
+        } else if (by=="acs.colnames") {
+         par(mfrow=c(1,j))
+        for (k in 1:j){
+          plot(x[,k], sub=acs.colnames(x)[k], conf.level=conf.level,
+      err.col=err.col, err.lwd=err.lwd, err.pch=err.pch,
+      err.cex=err.cex, err.lty=err.lty, labels=labels,...)
+       }        
+       }
+      }
+    }
+          )
+
 if (!isGeneric("acs.colnames<-")) {
           setGeneric("acs.colnames<-", def=function(x, value){standardGeneric("acs.colnames<-")})}else{}
         
@@ -1909,82 +1993,3 @@ currency.convert=function(object, rate="auto", newyear=NA_integer_, verbose=F){
                         , what, "\"", sep=""))}
         value
       }
-
-setMethod("plot",
-    signature(x = "acs"),
-    function (x, conf.level=.95, err.col="red", err.lwd=1,
-    err.pch="-", err.cex=2, err.lty=2, x.res=300, labels="auto",
-    by="geography", true.min=T, ...) 
-    {
-      # internal plot function to plot individual x-y plots with conf
-      # intervals, assume that either i or j or length 1
-      plot.xy.acs=function(x, object, conf.int.upper, conf.int.lower, estimates, labels, xlab, ylab, ...){
-        if(missing(xlab)) xlab=""
-        if(missing(ylab)) ylab=""       
-        plot(rep(x,2), c(conf.int.upper, conf.int.lower), type="n", xaxt="n", xlab=xlab, ylab=ylab,...)
-        axis(side=1, labels=labels, at=x, ...)
-        lines(x=matrix(c(x,x,rep(NA, length(x))), ncol=length(x), byrow=T), matrix(c(conf.int.lower, conf.int.upper, rep(NA, length(x))), ncol=length(x), byrow=T), col=err.col, lwd=err.lwd, lty=err.lty)
-        points(x, conf.int.upper, pch=err.pch, cex=err.cex, col=err.col)
-        points(x, conf.int.lower, pch=err.pch, cex=err.cex, col=err.col)
-        points(x, estimates,...)
-      }
-      acs.density.plot=function(x, type="l", xlim,
-        xlab=acs.colnames(x), ylab="Density Distribution",
-        conf.level, col="black", err.col, err.lwd, err.lty,
-        x.res, ...){
-        est=estimate(x)
-        err=standard.error(x)
-        if (missing(xlim)) xlim=c(est-(4*err), est+(4*err))
-        x.vals=seq(from=xlim[1], to=xlim[2], by=(xlim[2]-xlim[1])/x.res)
-        plot(x.vals, dnorm(x.vals, mean=est, sd=err), type=type,
-        xlab=xlab, ylab=ylab, col=col,...)
-      if (conf.level) {abline(v=qnorm(mean=est, sd=err, p=c(((1-conf.level)/2), (1-((1-conf.level)/2)))), col=err.col, lwd=err.lwd, lty=err.lty)}
-        }
-      i=dim(x)[1]
-      j=dim(x)[2]
-      if (length(x)==1) {
-        acs.density.plot(x, conf.level=conf.level, err.col=err.col,
-        err.lwd=err.lwd, err.lty=err.lty, x.res=x.res, ...)
-      } else if (i == 1 | j == 1){
-        con=confint(x, level=conf.level)
-        conf.int.upper=NA
-        conf.int.lower=NA
-        estimates=NA
-        if (i == 1) {                               # one row
-          if (identical(labels, "auto")) labels=acs.colnames(x)
-          for (k in 1:j){
-            conf.int.upper[k]=as.numeric(con[[k]][2])
-            if (true.min==T) {
-              conf.int.lower[k]=as.numeric(con[[k]][1])
-            } else {if (true.min==F) {true.min=0}
-                    conf.int.lower[k]=max(true.min, as.numeric(con[[k]][1]))}
-            estimates[k]=estimate(x)[1,k]
-            }}
-          else        {
-            if (identical(labels, "auto")) labels=geography(x)[[1]]
-          for (k in 1:i){                       # one column
-            conf.int.upper[k]=as.numeric(con[[1]][k,2])
-            if (true.min==T) {
-              conf.int.lower[k]=con[[1]][k,1]
-            } else {if (true.min==F) {true.min=0}
-                    conf.int.lower[k]=max(true.min, con[[1]][k,1])}
-            estimates[k]=estimate(x)[k,1]
-          }}
-        plot.xy.acs(x=1:max(i,j), object=x, conf.int.upper=conf.int.upper, conf.int.lower=conf.int.lower, estimates=estimates, labels=labels,...)
-      } else {
-        if (by=="geography"){
-          par(mfrow=c(i, 1))
-        for (k in 1:i){
-          plot(x[k,], sub=geography(x)[k,1], conf.level=conf.level, err.col=err.col, err.lwd=err.lwd, err.pch=err.pch, err.cex=err.cex, err.lty=err.lty, labels=labels,...)
-        }        
-        } else if (by=="acs.colnames") {
-         par(mfrow=c(1,j))
-        for (k in 1:j){
-          plot(x[,k], sub=acs.colnames(x)[k], conf.level=conf.level,
-      err.col=err.col, err.lwd=err.lwd, err.pch=err.pch,
-      err.cex=err.cex, err.lty=err.lty, labels=labels,...)
-       }        
-       }
-      }
-    }
-          )
